@@ -88,7 +88,7 @@ function on_zoom_show_all()
     var xml = xmlDoc.getElementsByTagName('job');
 
     if (!xml.length) {
-	window.status = "E : Impossible de zoomer " + url ;
+	window.status = "E : Can't zoom " + url ;
 	return ;
     }
     // calcul de la taille maxi des objets
@@ -340,7 +340,7 @@ function on_zoom_show_all()
     // [<job>]
     var x = xmlDoc.getElementsByTagName('job');
     if (!x.length) {
-	window.status = "E : Impossible de charger " + url ;
+	window.status = "E : Can't load " + url ;
 	return ;
     }
     update(x) ;
@@ -361,6 +361,8 @@ function on_zoom_show_all()
     // [<task>, <task>, <task>...]
     var x = xmlDoc.getElementsByTagName('task');
     update(x) ;
+
+    window.status = "I : Status updated" ;
  }
 
 /***************************************************
@@ -375,7 +377,7 @@ function mouseclick_listener(evt)
     var cmdline ;
 
     if (!task) {
-       window.status = "E : pas de " + id ;
+       window.status = "E : " + id + " not found";
        return ;
     }
 
